TerminalGeometry

Struct TerminalGeometry 

pub struct TerminalGeometry {
    pub size: TerminalSize,
    pub pixels: Option<TerminalPixels>,
}
A terminal geometry request including cell dimensions and optional pixels.

Fields

size: TerminalSize

The terminal size in character cells.

pixels: Option<TerminalPixels>

The terminal size in pixels, when the outer terminal exposes it.

Implementations

Source

impl TerminalGeometry

pub const fn new(cols: u16, rows: u16) -> Self

Creates terminal geometry from cell dimensions.

pub const fn from_size(size: TerminalSize) -> Self

Creates terminal geometry from an existing cell size.

pub const fn with_pixels(self, pixels: TerminalPixels) -> Self

Adds pixel dimensions to this geometry.